@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2007 Jari-Matti Mäkelä <jmjm@iki.fi>
-    SPDX-FileCopyrightText: 2008-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2008-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -72,20 +72,20 @@ void DCodeAccessorMethod::updateContent()
             QString indent = getIndentation();
             QString endLine = UMLApp::app()->commonPolicy()->getNewLineEndingChars();
             if(maxOccurs > 0)
-                text += QLatin1String("if (") + fieldName + QLatin1String(".size() < ")+ QString::number(maxOccurs) + QLatin1String(") {") + endLine + indent;
-            text += fieldName + QLatin1String(".add(value);");
+                text += QStringLiteral("if (") + fieldName + QStringLiteral(".size() < ")+ QString::number(maxOccurs) + QStringLiteral(") {") + endLine + indent;
+            text += fieldName + QStringLiteral(".add(value);");
             if(maxOccurs > 0)
             {
-                text += endLine + QLatin1String("} else {") + endLine;
-                text += indent + QLatin1String("System.err.println(\"ERROR: Cant add") + fieldType + QLatin1String(" to ") + fieldName + QLatin1String(", minimum number of items reached.\");") + endLine + QLatin1Char('}') + endLine;
+                text += endLine + QStringLiteral("} else {") + endLine;
+                text += indent + QStringLiteral("System.err.println(\"ERROR: Cant add") + fieldType + QStringLiteral(" to ") + fieldName + QStringLiteral(", minimum number of items reached.\");") + endLine + QLatin1Char('}') + endLine;
             }
             break;
         }
     case CodeAccessorMethod::GET:
-        text = QLatin1String("return ") + fieldName + QLatin1Char(';');
+        text = QStringLiteral("return ") + fieldName + QLatin1Char(';');
         break;
     case CodeAccessorMethod::LIST:
-        text = QLatin1String("return (List) ") + fieldName + QLatin1Char(';');
+        text = QStringLiteral("return (List) ") + fieldName + QLatin1Char(';');
         break;
     case CodeAccessorMethod::REMOVE:
         {
@@ -95,17 +95,17 @@ void DCodeAccessorMethod::updateContent()
             QString indent = getIndentation();
 
             if(minOccurs > 0)
-                text += QLatin1String("if (") + fieldName + QLatin1String(".size() >= ")+ QString::number(minOccurs) + QLatin1String(") {") + endLine + indent;
-            text += fieldName + QLatin1String(".remove(value);");
+                text += QStringLiteral("if (") + fieldName + QStringLiteral(".size() >= ")+ QString::number(minOccurs) + QStringLiteral(") {") + endLine + indent;
+            text += fieldName + QStringLiteral(".remove(value);");
             if(minOccurs > 0)
             {
-                text += endLine + QLatin1String("} else {") + endLine;
-                text += indent + QLatin1String("System.err.println(\"ERROR: Cant remove") + fieldType + QLatin1String(" from ") + fieldName + QLatin1String(", minimum number of items reached.\");") + endLine + QLatin1Char('}') + endLine;
+                text += endLine + QStringLiteral("} else {") + endLine;
+                text += indent + QStringLiteral("System.err.println(\"ERROR: Cant remove") + fieldType + QStringLiteral(" from ") + fieldName + QStringLiteral(", minimum number of items reached.\");") + endLine + QLatin1Char('}') + endLine;
             }
             break;
         }
     case CodeAccessorMethod::SET:
-        text = fieldName + QLatin1String(" = value;");
+        text = fieldName + QStringLiteral(" = value;");
         break;
     default:
         // do nothing
@@ -120,9 +120,9 @@ void DCodeAccessorMethod::updateMethodDeclaration()
     DCodeClassField * dfield = dynamic_cast<DCodeClassField*>(getParentClassField());
 
     // Check for dynamic casting failure!
-    if (dfield == 0)
+    if (dfield == nullptr)
     {
-        uError() << "dfield: invalid dynamic cast";
+        logError0("dfield: invalid dynamic cast");
         return;
     }
 
@@ -162,36 +162,36 @@ void DCodeAccessorMethod::updateMethodDeclaration()
 
     switch(getType()) {
     case CodeAccessorMethod::ADD:
-        methodName = QLatin1String("add") + Codegen_Utils::capitalizeFirstLetter(fieldType);
-        methodReturnType = QLatin1String("void");
-        methodParams = objectType + QLatin1String(" value ");
-        headerText = QLatin1String("Add an object of type ") + objectType + QLatin1String(" to the List ") + fieldName + endLine + getParentObject()->doc() + endLine + QLatin1String("@return void");
+        methodName = QStringLiteral("add") + Codegen_Utils::capitalizeFirstLetter(fieldType);
+        methodReturnType = QStringLiteral("void");
+        methodParams = objectType + QStringLiteral(" value ");
+        headerText = QStringLiteral("Add an object of type ") + objectType + QStringLiteral(" to the List ") + fieldName + endLine + getParentObject()->doc() + endLine + QStringLiteral("@return void");
         break;
     case CodeAccessorMethod::GET:
-        methodName = QLatin1String("get") + Codegen_Utils::capitalizeFirstLetter(fieldName);
+        methodName = QStringLiteral("get") + Codegen_Utils::capitalizeFirstLetter(fieldName);
         methodReturnType = fieldType;
-        headerText = QLatin1String("Get the value of ") + fieldName + endLine + getParentObject()->doc() + endLine + QLatin1String("@return the value of ") + fieldName;
+        headerText = QStringLiteral("Get the value of ") + fieldName + endLine + getParentObject()->doc() + endLine + QStringLiteral("@return the value of ") + fieldName;
         break;
     case CodeAccessorMethod::LIST:
-        methodName = QLatin1String("get") + Codegen_Utils::capitalizeFirstLetter(fieldType) + QLatin1String("List");
-        methodReturnType = QLatin1String("List");
-        headerText = QLatin1String("Get the list of ") + fieldName + endLine + getParentObject()->doc() + endLine + QLatin1String("@return List of ") + fieldName;
+        methodName = QStringLiteral("get") + Codegen_Utils::capitalizeFirstLetter(fieldType) + QStringLiteral("List");
+        methodReturnType = QStringLiteral("List");
+        headerText = QStringLiteral("Get the list of ") + fieldName + endLine + getParentObject()->doc() + endLine + QStringLiteral("@return List of ") + fieldName;
         break;
     case CodeAccessorMethod::REMOVE:
-        methodName = QLatin1String("remove") + Codegen_Utils::capitalizeFirstLetter(fieldType);
-        methodReturnType = QLatin1String("void");
-        methodParams = objectType + QLatin1String(" value ");
-        headerText = QLatin1String("Remove an object of type ") + objectType + QLatin1String(" from the List ") + fieldName + endLine + getParentObject()->doc();
+        methodName = QStringLiteral("remove") + Codegen_Utils::capitalizeFirstLetter(fieldType);
+        methodReturnType = QStringLiteral("void");
+        methodParams = objectType + QStringLiteral(" value ");
+        headerText = QStringLiteral("Remove an object of type ") + objectType + QStringLiteral(" from the List ") + fieldName + endLine + getParentObject()->doc();
         break;
     case CodeAccessorMethod::SET:
-        methodName = QLatin1String("set") + Codegen_Utils::capitalizeFirstLetter(fieldName);
-        methodReturnType = QLatin1String("void");
-        methodParams = fieldType + QLatin1String(" value ");
-        headerText = QLatin1String("Set the value of ") + fieldName + endLine + getParentObject()->doc() + endLine;
+        methodName = QStringLiteral("set") + Codegen_Utils::capitalizeFirstLetter(fieldName);
+        methodReturnType = QStringLiteral("void");
+        methodParams = fieldType + QStringLiteral(" value ");
+        headerText = QStringLiteral("Set the value of ") + fieldName + endLine + getParentObject()->doc() + endLine;
         break;
     default:
         // do nothing..no idea what this is
-        uWarning()<<"Warning: cant generate DCodeAccessorMethod for type: "<<getType();
+        logWarn1("Cannot generate DCodeAccessorMethod for type: %1", getType());
         break;
     }
 
@@ -200,8 +200,8 @@ void DCodeAccessorMethod::updateMethodDeclaration()
         getComment()->setText(headerText);
 
     // set start/end method text
-    setStartMethodText(strVis + QLatin1Char(' ') + methodReturnType + QLatin1Char(' ') + methodName + QLatin1String(" (") + methodParams + QLatin1String(") {"));
-    setEndMethodText(QLatin1String("}"));
+    setStartMethodText(strVis + QLatin1Char(' ') + methodReturnType + QLatin1Char(' ') + methodName + QStringLiteral(" (") + methodParams + QStringLiteral(") {"));
+    setEndMethodText(QStringLiteral("}"));
 }
 
 void DCodeAccessorMethod::update()
