@@ -29,7 +29,7 @@
 #include "uml.h"
 
 // qt includes
-#include <QRegExp>
+#include <QRegularExpression>
 
 DEBUG_REGISTER(JavaClassifierCodeDocument)
 
@@ -75,10 +75,10 @@ QString JavaClassifierCodeDocument::getPath () const
     path = path.simplified();
 
     // Replace all blanks with underscore
-    path.replace(QRegExp(QStringLiteral(" ")), QStringLiteral("_"));
+    path.replace(QRegularExpression(QStringLiteral(" ")), QStringLiteral("_"));
 
-    path.replace(QRegExp(QStringLiteral("\\.")),QStringLiteral("/"));
-    path.replace(QRegExp(QStringLiteral("::")), QStringLiteral("/"));
+    path.replace(QRegularExpression(QStringLiteral("\\.")),QStringLiteral("/"));
+    path.replace(QRegularExpression(QStringLiteral("::")), QStringLiteral("/"));
 
     return path.toLower();
 }
@@ -97,9 +97,9 @@ void JavaClassifierCodeDocument::init ()
                              // CodeGenFactory::newCodeClassField(this)
                              // but "this" is still in construction at that time.
 
-    classDeclCodeBlock = 0;
-    operationsBlock = 0;
-    constructorBlock = 0;
+    classDeclCodeBlock = nullptr;
+    operationsBlock = nullptr;
+    constructorBlock = nullptr;
 
     // this will call updateContent() as well as other things that sync our document.
     synchronize();
@@ -113,9 +113,9 @@ void JavaClassifierCodeDocument::init ()
 bool JavaClassifierCodeDocument::addCodeOperation (CodeOperation * op)
 {
     if (!op->getParentOperation()->isLifeOperation())
-        return operationsBlock == 0 ? false : operationsBlock->addTextBlock(op);
+        return operationsBlock == nullptr ? false : operationsBlock->addTextBlock(op);
     else
-        return constructorBlock == 0 ? false : constructorBlock->addTextBlock(op);
+        return constructorBlock == nullptr ? false : constructorBlock->addTextBlock(op);
 }
 
 // Sigh. NOT optimal. The only reason that we need to have this
@@ -251,9 +251,9 @@ JavaClassDeclarationBlock * JavaClassifierCodeDocument::getClassDecl()
 void JavaClassifierCodeDocument::resetTextBlocks()
 {
     // all special pointers to text blocks need to be zero'd out
-    operationsBlock = 0;
-    constructorBlock = 0;
-    classDeclCodeBlock = 0;
+    operationsBlock = nullptr;
+    constructorBlock = nullptr;
+    classDeclCodeBlock = nullptr;
 
     // now do traditional release of text blocks.
     ClassifierCodeDocument::resetTextBlocks();
@@ -270,7 +270,7 @@ void JavaClassifierCodeDocument::updateContent()
 {
     // Gather info on the various fields and parent objects of this class...
     UMLClassifier * c = getParentClassifier();
-    Q_ASSERT(c != 0);
+    Q_ASSERT(c != nullptr);
     CodeGenerationPolicy * commonPolicy = UMLApp::app()->commonPolicy();
     CodeGenPolicyExt * pe = UMLApp::app()->policyExt();
     JavaCodeGenerationPolicy * policy = dynamic_cast<JavaCodeGenerationPolicy*>(pe);
@@ -313,7 +313,7 @@ void JavaClassifierCodeDocument::updateContent()
     // PACKAGE CODE BLOCK
     //
     QString pkgs = getPackage();
-    pkgs.replace(QRegExp(QStringLiteral("::")), QStringLiteral("."));
+    pkgs.replace(QRegularExpression(QStringLiteral("::")), QStringLiteral("."));
     QString packageText = getPackage().isEmpty() ? QString() : QStringLiteral("package ") + pkgs + QLatin1Char(';') + endLine;
     CodeBlockWithComments * pblock = addOrUpdateTaggedCodeBlockWithComments(QStringLiteral("packages"), packageText, QString(), 0, false);
     if (packageText.isEmpty() && pblock->contentType() == CodeBlock::AutoGenerated)
